@@ -80,11 +80,12 @@ assign("options", list(
     trace=0,
     tol=1e-6,
     gamma=1,
-    backtrace=TRUE,
+    backtrack="wolfe",
     ngamma=0,
     iter.max=300,
     eval.max=250,
     constrain=FALSE,
+    allow.negative.variance=FALSE,
     silent=TRUE,
     progressbarstyle=3,
     itol=1e-16,
