@@ -198,7 +198,8 @@ categorical2dummy <- function(x,data,silent=TRUE,...) {
 
 `procdata.lvm` <-
   function(x,data,categorical=FALSE,
-    na.method=ifelse(any(is.na(data[,intersect(colnames(data),manifest(x))])),"complete.obs","pairwise.complete.obs")
+    na.method=ifelse(any(is.na(data[,intersect(colnames(data),manifest(x))])),"complete.obs","pairwise.complete.obs"),
+    missing=FALSE
     ) {
     if (is.numeric(data) & !is.list(data)) {
       data <- rbind(data)
@@ -227,17 +228,19 @@ categorical2dummy <- function(x,data,silent=TRUE,...) {
       if (n==1) {
         S <- diag(nrow=ncol(mydata)); colnames(S) <- rownames(S) <- obs
       }
-      if (na.method=="complete.obs") {
-        mydata <- na.omit(mydata)
-        n <- nrow(mydata)
-        mu <- colMeans(mydata)
-        if (is.null(S))
-          S <- (n-1)/n*cov(mydata) ## MLE variance matrix of observed variables
+      if (na.method=="complete.obs" && !missing) {
+        mydata0 <- na.omit(mydata)
+        n <- nrow(mydata0)
+        mu <- colMeans(mydata0)
+        if (is.null(S) && n>2) 
+            S <- (n-1)/n*cov(mydata0) ## MLE variance matrix of observed variables
+        rm(mydata0)
       }
       nS <- is.null(S) || any(is.na(S))
       if (na.method=="pairwise.complete.obs" || nS) {
           mu <- colMeans(mydata,na.rm=TRUE)
           if (nS) {
+              n <- nrow(mydata)
               S <- (n-1)/n*cov(mydata,use="pairwise.complete.obs")
               S[is.na(S)] <- 1e-3
           }
@@ -305,8 +308,9 @@ function(M, upper=TRUE) {
 ###{{{ Inverse/pseudo
 
 ##' @export
-Inverse <- function(X,tol=lava.options()$itol,det=TRUE,names=!chol,chol=FALSE) {
+Inverse <- function(X,tol=lava.options()$itol,det=TRUE,names=!chol,chol=FALSE,symmetric=FALSE) {
     n <- NROW(X)
+                                        # return(structure(solve(X),))
     if (n==1L) {
         res <- 1/X
         if (det) attributes(res)$det <- X
@@ -319,15 +323,27 @@ Inverse <- function(X,tol=lava.options()$itol,det=TRUE,names=!chol,chol=FALSE) {
         if (det) attributes(res)$det <- prod(diag(L)^2)
         if (chol) attributes(res)$chol <- X        
     } else {
-        svdX <- svd(X)
+        if(symmetric){
+            decomp <- eigen(X, symmetric = TRUE)
+            D <- decomp$values
+            U <- decomp$vectors
+            V <- decomp$vectors
+        }else{
+            X.svd <- svd(X)
+            U <- X.svd$u
+            V <- X.svd$v
+            D <- X.svd$d
+        }
         id0 <- numeric(n)
-        idx <- which(svdX$d>tol)
-        id0[idx] <- 1/svdX$d[idx]
-        res <- with(svdX, v%*%diag(id0,nrow=length(id0))%*%t(u))
-        if (det)
-            attributes(res)$det <- prod(svdX$d[svdX$d>tol])
+        idx <- which(abs(D)>tol)
+        id0[idx] <- 1/D[idx]
+        res <- V%*%diag(id0,nrow=length(id0))%*%t(U)
+        
+        if (det) 
+            attributes(res)$det <- prod(D[D>tol])
         attributes(res)$pseudo <- (length(idx)<n)
-        attributes(res)$minSV <- min(svdX$d)
+        attributes(res)$minSV <- min(D)
+        
     }
     if (names && !is.null(colnames(X))) dimnames(res) <- list(colnames(X),colnames(X))
     return(res)
@@ -444,7 +460,7 @@ getoutcome <- function(formula,sep) {
   } else {
     res <- paste(deparse(formula[[2]]),collapse="")
   }
-  if (!missing(sep)) {
+  if (!missing(sep) && length(aa$term.labels)>0) {
       attributes(res)$x <- lapply(strsplit(aa$term.labels,"\\|")[[1]],
                                   function(x) as.formula(paste0("~",x)))
   } else {
